Function peripheral_by_compatible
pub fn peripheral_by_compatible(c: &str) -> Option<&'static Peripheral>Expand description
find the first enabled peripheral for which any compatible string equals c
pub fn peripheral_by_compatible(c: &str) -> Option<&'static Peripheral>find the first enabled peripheral for which any compatible string equals c