peripheral_by_path

Function peripheral_by_path 

pub fn peripheral_by_path(path: &str) -> Option<&'static Peripheral>
find a peripheral by its full path from root, with or without unit addresses e.g. soc/i2c@40005400/lsm6dsl@6a or soc/i2c/lsm6dsl at each level the first sibling whose name matches is taken