Function peripherals_by_compatible
pub fn peripherals_by_compatible(
c: &str,
) -> impl Iterator<Item = &'static Peripheral>Expand description
iterate all enabled peripherals for which any compatible string equals c
pub fn peripherals_by_compatible(
c: &str,
) -> impl Iterator<Item = &'static Peripheral>iterate all enabled peripherals for which any compatible string equals c