Function peripheral_by_name_under
pub fn peripheral_by_name_under(
name: &str,
parent_node: usize,
) -> Option<&'static Peripheral>Expand description
find a peripheral by name scoped to a specific parent node index safe form of name lookup since node names are only unique among siblings